@@ -1,5 +1,8 @@
 /* Customized config.h for Android builds */
 
+/* disable the high quality mixer (build only with the standart mixer) */
+/* #define NO_HQMIXER */
+
 /* Define if the OpenSL ES driver is compiled */
 #define DRV_OSLES 1
 /* Define if you want an .aiff file writer driver */
@@ -25,12 +28,10 @@
 #define HAVE_SRANDOM 1
 #define HAVE_STDINT_H 1
 #define HAVE_STDLIB_H 1
-#define HAVE_STRCASECMP 1
-#define HAVE_STRDUP 1
 #define HAVE_STRING_H 1
-#define HAVE_STRINGS_H 1
 #define HAVE_STRSTR 1
 #define HAVE_SYS_IOCTL_H 1
 #define HAVE_SYS_STAT_H 1
 #define HAVE_SYS_TYPES_H 1
 #define HAVE_SYS_WAIT_H 1
+
