@@ -21,8 +21,6 @@
 
 /*==============================================================================
 
-  $Id$
-
   Driver for output to a file called MUSIC.AIFF [or .AIF on Windows].
 
 ==============================================================================*/
@@ -65,6 +63,12 @@ static	ULONG	gAiffDumpSize = 0;
 #ifdef SUNOS
 extern int fclose(FILE *);
 #endif
+#ifdef __VBCC__
+#define unlink remove
+#endif
+#ifdef _WIN32
+#define unlink _unlink
+#endif
 
 static void	AIFF_ConvertToIeeeExtended (double theValue, char *theBytes);
 static void	AIFF_PutHeader (void);
