@@ -58,7 +58,7 @@ static	MUNPACKER unpackers[] = {
 	NULL
 };
 
-UWORD finetune[16]={
+const UWORD finetune[16] = {
 	8363,8413,8463,8529,8581,8651,8723,8757,
 	7895,7941,7985,8046,8107,8169,8232,8280
 };
@@ -133,44 +133,44 @@ BOOL ReadComment(UWORD len)
 
 BOOL ReadLinedComment(UWORD len,UWORD linelen)
 {
-	CHAR *tempcomment,*line,*storage;
-	UWORD total=0,t,lines;
-	int i;
+	/* Adapted from the OpenMPT project, C'ified. */
+	CHAR *buf, *storage, *p;
+	size_t numlines, line, fpos, cpos, lpos, cnt;
 
-	lines = (len + linelen - 1) / linelen;
-	if (len) {
-		if(!(tempcomment=(CHAR*)MikMod_malloc(len+1))) return 0;
-		if(!(storage=(CHAR*)MikMod_malloc(linelen+1))) {
-			MikMod_free(tempcomment);
-			return 0;
-		}
-		memset(tempcomment, ' ', len);
-		_mm_read_UBYTES(tempcomment,len,modreader);
+	if (!linelen) return 0;
+	if (!len) return 1;
 
-		/* compute message length */
-		for(line=tempcomment,total=t=0;t<lines;t++,line+=linelen) {
-			for(i=linelen;(i>=0)&&(line[i]==' ');i--) line[i]=0;
-			for(i=0;i<linelen;i++) if (!line[i]) break;
-			total+=1+i;
-		}
+	if (!(buf = (CHAR *) MikMod_malloc(len))) return 0;
+	numlines = (len + linelen - 1) / linelen;
+	cnt = (linelen + 1) * numlines;
+	if (!(storage = (CHAR *) MikMod_malloc(cnt + 1))) {
+		MikMod_free(buf);
+		return 0;
+	}
 
-		if(total>lines) {
-			if(!(of.comment=(CHAR*)MikMod_malloc(total+1))) {
-				MikMod_free(storage);
-				MikMod_free(tempcomment);
-				return 0;
+	_mm_read_UBYTES(buf,len,modreader);
+	storage[cnt] = 0;
+	for (line = 0, fpos = 0, cpos = 0; line < numlines; line++, fpos += linelen, cpos += (linelen + 1))
+	{
+		cnt = len - fpos;
+		if (cnt > linelen) cnt = linelen;
+		p = storage + cpos;
+		memcpy(p, buf + fpos, cnt);
+		p[cnt] = '\r';
+		/* fix weird chars */
+		for (lpos = 0; lpos < linelen; lpos++, p++) {
+			switch (*p) {
+			case '\0':
+			case '\n':
+			case '\r':
+				*p = ' ';
+				break;
 			}
-
-			/* convert message */
-			for(line=tempcomment,t=0;t<lines;t++,line+=linelen) {
-				for(i=0;i<linelen;i++) if(!(storage[i]=line[i])) break;
-				storage[i]=0; /* if (i==linelen) */
-				strcat(of.comment,storage);strcat(of.comment,"\r");
-			}
-			MikMod_free(storage);
-			MikMod_free(tempcomment);
 		}
 	}
+
+	of.comment = storage;
+	MikMod_free(buf);
 	return 1;
 }
 
@@ -511,7 +511,7 @@ static MODULE* Player_LoadGeneric_internal(MREADER *reader,int maxchan,BOOL curi
 
 	if(!l) {
 		_mm_errno = MMERR_NOT_A_MODULE;
-err1:		if(modreader!=reader) {
+		if(modreader!=reader) {
 			_mm_delete_mem_reader(modreader);
 			modreader=reader;
 			MikMod_free(unpk);
@@ -523,7 +523,17 @@ err1:		if(modreader!=reader) {
 	}
 
 	/* init unitrk routines */
-	if(!UniInit()) goto err1;
+	if(!UniInit()) {
+		if(modreader!=reader) {
+			_mm_delete_mem_reader(modreader);
+			modreader=reader;
+			MikMod_free(unpk);
+		}
+		if(_mm_errorhandler) _mm_errorhandler();
+		_mm_rewind(modreader);
+		_mm_iobase_revert(modreader);
+		return NULL;
+	}
 
 	/* init the module structure with vanilla settings */
 	memset(&of,0,sizeof(MODULE));
@@ -554,7 +564,15 @@ err1:		if(modreader!=reader) {
 	if(ok) ok = ((mf=ML_AllocUniMod()) != NULL);
 	if(!ok) {
 		ML_FreeEx(&of);
-		goto err1;
+		if(modreader!=reader) {
+			_mm_delete_mem_reader(modreader);
+			modreader=reader;
+			MikMod_free(unpk);
+		}
+		if(_mm_errorhandler) _mm_errorhandler();
+		_mm_rewind(modreader);
+		_mm_iobase_revert(modreader);
+		return NULL;
 	}
 
 	/* If the module doesn't have any specific panning, create a
